@@ -54,8 +54,7 @@ TipQalc::TipQalc(QWidget *parent) :
     if (settings.contains("tipPercent"))
     {
         QString tipPercent = settings.value("tipPercent").toString();
-        ui->tipLine->clear();
-        ui->tipLine->insert(tipPercent);
+        ui->tipLine->setText(tipPercent);
     }
 
     manageTaxInputWidgets();
@@ -147,9 +146,9 @@ void TipQalc::adjustPersons(int value)
 
     value = currentValue + value;
     if (value < 1) value = 1;
+    if (value > 99) value = 99;
 
-    ui->personsLine->clear();
-    ui->personsLine->insert(QString::number(value));
+    ui->personsLine->setText(QString::number(value));
 
     if (total) calculateTip();
 }
@@ -164,9 +163,9 @@ void TipQalc::adjustTip(int value)
 
     value = currentValue + value;
     if (value < 0) value = 0;
+    if (value > 99) value = 99;
 
-    ui->tipLine->clear();
-    ui->tipLine->insert(QString::number(value));
+    ui->tipLine->setText(QString::number(value));
 
     if (total) calculateTip();
 }
@@ -185,7 +184,7 @@ float TipQalc::round( float x, int precision=2)
 */
 float TipQalc::roundWeighted( float x)
 {
-    return int(x + (x<0 ? -0.25 : 0.75));
+    return int(x + (x<0 ? -0.20 : 0.80));
 }
 
 /*
